VSTUtils Framework
==================

Small framework for easy generates web-applications
(PWA/Progressive Web Application and SPA/Single Page Application).
It uses OpenAPI schema for GUI rendering based over the REST API
and also provides the ability to generate documentation for the API based on the schema.
By default GUI based on AdminLTE dashboard and Vue templates.

Review a special section in the documentation for a QuickStart development - https://vstutils.vstconsulting.net/quickstart.html.


.. image:: https://img.shields.io/github/license/vstconsulting/vstutils.svg
    :target: https://github.com/vstconsulting/vstutils/blob/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/pypi/v/vstutils?color=green
    :alt: PyPI

.. image:: https://img.shields.io/pypi/dm/vstutils
    :alt: PyPI - Downloads

Development Status
~~~~~~~~~~~~~~~~~~

.. image:: https://gitlab.com/vstconsulting/vstutils/badges/master/pipeline.svg
    :target: https://gitlab.com/vstconsulting/vstutils/commits/master
    :alt: Pipeline status

.. image:: https://gitlab.com/vstconsulting/vstutils/badges/master/coverage.svg
    :target: https://gitlab.com/vstconsulting/vstutils/pipelines
    :alt: Coverage report

.. image:: https://img.shields.io/pypi/djversions/vstutils?color=green
    :alt: PyPI - Django Version

.. image:: https://img.shields.io/pypi/pyversions/vstutils?color=green
    :target: https://pypi.org/project/vstutils/
    :alt: PyPI - Python Version

.. image:: https://img.shields.io/tokei/lines/gitlab/vstconsulting/vstutils?color=green
    :alt: Lines of code

.. image:: https://img.shields.io/github/last-commit/vstconsulting/vstutils
    :target: https://github.com/vstconsulting/vstutils/commits/master
    :alt: GitHub last commit


Browser support
---------------
Supported `browserslist <https://browserl.ist/?q=%3E+0.25%25+and+not+dead+and+not+IE+11>`_.


Public projects
---------------

* Polemarch (https://polemarch.org/)
* SkillsChecked (Nurse recruitment app).


License
-------

VSTUtils is licensed under the terms of the Apache License 2.0.
See the file "LICENSE" for more information.

Copyright 2018-2021 VST Consulting
